import * as _nuxt_schema from '@nuxt/schema';

interface ModuleOptions {
    /**
     * Will ensure a title is always set by providing a fallback title based on the casing the last slug segment.
     *
     * @default true
     */
    fallbackTitle?: boolean;
    /**
     * Will set up a number of defaults for meta tags and Schema.org, if the modules and config are available.
     *
     * @default true
     */
    automaticDefaults?: boolean;
    /**
     * When enabled, it will whitelist the query parameters that are allowed in the canonical URL.
     */
    canonicalQueryWhitelist?: string[];
    /**
     * When enabled, it will redirect any request to the canonical domain (site url) using a 301 redirect on non-dev environments.
     *
     * E.g if the site url is 'www.example.com' and the user visits 'example.com',
     * they will be redirected to 'www.example.com'.
     *
     * This is useful for SEO as it prevents duplicate content and consolidates page rank.
     *
     * @default false
     */
    redirectToCanonicalSiteUrl?: boolean;
    /**
     * Whether the module should be loaded.
     */
    enabled: boolean;
    /**
     * Whether the debugging mode should be enabled.
     *
     * @default `nuxt.options.debug`
     */
    debug: boolean;
    /**
     * Whether the Nuxt SEO splash should be shown when Nuxt is started.
     *
     * @default `nuxt.options.dev`
     */
    splash: boolean;
}
declare const _default: _nuxt_schema.NuxtModule<ModuleOptions>;

export { type ModuleOptions, _default as default };
